@@ -21,6 +21,15 @@
 # include <config.h>
 #endif
 
+#if HAVE_LOCALE_H
+# include <locale.h>
+#else
+# define setlocale(Category, Locale)
+#endif
+
+#include <libintl.h>
+#define _(Text) gettext ((Text))
+
 #include <stdio.h>
 
 #if STDC_HEADERS
@@ -44,16 +53,19 @@
 # define EXIT_FAILURE 1
 #endif
 
-#if __STDC__
-# define _(Args) Args
-#else
-# define _(Args) ()
+#ifndef __P
+# if __STDC__
+#  define __P(Args) Args
+# else
+#  define __P(Args) ()
+# endif
 #endif
 
-void *xmalloc _((int));
-char *xstrdup _((const char *));
-int argmatch _((const char *, const char *const *));
-void error _((int, int, const char *, ...));
+void *xmalloc __P ((int));
+char *xstrdup __P ((const char *));
+int argmatch __P ((const char *, const char *const *));
+void error __P ((int, int, const char *, ...));
+extern void (*error_print_progname) __P ((void));
 
 /* Description of a charset.  */
 
@@ -71,8 +83,6 @@ struct charset
 
 /* Description of a single step of recoding.  */
 
-typedef enum quality QUALITY;
-
 enum quality
   {
     REVERSIBLE,			/* reversible one to one recoding */
@@ -83,6 +93,10 @@ enum quality
     MANY_TO_MANY		/* one or many characters to one or many */
   };
 
+/* The HP-UX 9.01 compiler says `Unknown size "QUALITY"', if I put the
+   typedef before the enum declaration, as I'm used to do.  Sigh!  */
+typedef enum quality QUALITY;
+
 typedef struct step STEP;
 
 struct step
@@ -90,8 +104,8 @@ struct step
     CHARSET *before;		/* charset before conversion */
     CHARSET *after;		/* charset after conversion */
     QUALITY quality;		/* recoding quality */
-    void (*init_recode) _((STEP *));
-    int (*file_recode) _((const STEP *, FILE *, FILE *));
+    void (*init_recode) __P ((STEP *));
+    int (*file_recode) __P ((const STEP *, FILE *, FILE *));
     const unsigned char *one_to_one; /* recoding array of 256 chars */
     const char *const *one_to_many; /* recoding array of 256 strings */
     int conversion_cost;	/* cost for this single step only */
@@ -128,37 +142,37 @@ extern int decoding_charset_flag;
 extern const unsigned char *one_to_same;
 extern CHARSET *rfc1345;
 
-void usage _((int));
-const char *quality_to_string _((QUALITY));
-QUALITY merge_qualities _((QUALITY, QUALITY));
-void declare_step _((const char *, const char *, QUALITY, void (*) (STEP *),
-		     int (*) (const STEP *, FILE *, FILE *)));
-void declare_double_step _((DOUBLE_TABLE *, const char *, int));
-unsigned char *invert_table _((const unsigned char *));
-void complete_pairs _((STEP *, int, const KNOWN_PAIR *, int, int));
-int file_one_to_one _((const STEP *, FILE *, FILE *));
-int file_one_to_many _((const STEP *, FILE *, FILE *));
+void usage __P ((int));
+const char *quality_to_string __P ((QUALITY));
+QUALITY merge_qualities __P ((QUALITY, QUALITY));
+void declare_step __P ((const char *, const char *, QUALITY, void (*) (STEP *),
+			int (*) (const STEP *, FILE *, FILE *)));
+void declare_double_step __P ((DOUBLE_TABLE *, const char *, int));
+unsigned char *invert_table __P ((const unsigned char *));
+void complete_pairs __P ((STEP *, int, const KNOWN_PAIR *, int, int));
+int file_one_to_one __P ((const STEP *, FILE *, FILE *));
+int file_one_to_many __P ((const STEP *, FILE *, FILE *));
 
 /* charname.c.  */
 
-char *symbol_to_charname _((const char *));
+char *symbol_to_charname __P ((const char *));
 
 /* charset.c.  */
 
 extern CHARSET charset_array[];
 extern int number_of_charsets;
 
-void decode_known_pairs _((const char *));
-void prepare_charset_initialization _((void));
-CHARSET *find_charset _((const char *));
-void declare_alias _((const char *, const char *));
-void make_argmatch_array _((void));
-const char *clean_charset_name _((const char *));
+void decode_known_pairs __P ((const char *));
+void prepare_charset_initialization __P ((void));
+CHARSET *find_charset __P ((const char *));
+void declare_alias __P ((const char *, const char *));
+void make_argmatch_array __P ((void));
+const char *clean_charset_name __P ((const char *));
 
-void list_all_charsets _((CHARSET *));
-void init_table_for_rfc1345 _((STEP *));
-void list_concise_charset _((CHARSET *));
-void list_full_charset _((CHARSET *));
+void list_all_charsets __P ((CHARSET *));
+void init_table_for_rfc1345 __P ((STEP *));
+void list_concise_charset __P ((CHARSET *));
+void list_full_charset __P ((CHARSET *));
 
 /* Debugging the memory allocator.  */
 
